==> piwigo-2.1.5.zip: piwigo/language/lv_LV/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = "Instalacija";
$lang['Basic configuration'] = "Pamatkonfiguracija";
$lang['Default gallery language'] = "Galerijas valoda pec noklusešanas";
$lang['Database configuration'] = "Datubazes konfiguracija";
$lang['Admin configuration'] = "Administratora konfiguracija";
$lang['Start Install'] = "Sakt instalaciju";
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = "e-pasta adresei jaizskatas xxx@yyy.eee (piemeram : jack@altern.org)";
$lang['Webmaster login'] = "Webmastera logins";
$lang['It will be shown to the visitors. It is necessary for website administration'] = "Tas tiks radits apmekletajiem. Tas nepieciešams web lapas administrešanai";
$lang['Connection to server succeed, but it was impossible to connect to database'] = "Savienojums ar serveri sekmigs, bet savienojums ar datu bazi nav iespejams";
$lang['Can\'t connect to server'] = "Nevar savienoties ar serveri";
$lang['Database type'] = "Datubazes tips";
$lang['The type of database your piwigo data will be store in'] = "Datu bazes tips, kur tiks galbati Jusu Ptwigo dati.";
$lang['Host'] = "Hosts";
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = "localhost, sql.multimania.com, toto.freesurf.fr";
$lang['User'] = "Lietotajs";
$lang['user login given by your host provider'] = "lietotaja logins, ko pieškir Jusu hosta pakalpojuma sniedzejs";
$lang['Password'] = "Parole";
$lang['user password given by your host provider'] = " lietotaja parole, ko pieškir Jusu hosta pakalpojuma sniedzejs";
$lang['Database name'] = "Datu bazes nosaukums";
$lang['also given by your host provider'] = "ari pieškir Jusu hosta pakalpojuma sniedzejs";
$lang['Database table prefix'] = "Datu bazes tabulas prefikss";
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = "datu bazes tabulu nosaukumi bus ar šo prefiksu (lauj labak parvaldit Jusu tabulas)";
$lang['enter a login for webmaster'] = "ievadit webmastera loginu";
$lang['webmaster login can\'t contain characters \' or "'] = "webmastera logins nedrikst saturet ' vai \"";
$lang['please enter your password again'] = "ludzu ievadiet Jusu paroli no jauna";
$lang['Webmaster password'] = "Webmastera parole";
$lang['Keep it confidential, it enables you to access administration panel'] = "Esiet konfidenciali, tas lauj pieklut administratora panelim";
$lang['Password [confirm]'] = "Parole [apstiprinat]";
$lang['verification'] = "parbaude";
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = "Vajag palidzibu? Uzdodiet savu jautajumu <a href=\"%s\">Piwigo sludinajumos</a>.";
$lang['Webmaster mail address'] = "Webmaster mail address";
$lang['Visitors will be able to contact site administrator with this mail'] = "Apmekletaji vares izmantot šo e-pastu, lai sazinatos ar lapas administratoru";
$lang['PHP 5 is required'] = "nepieciešams PHP 5 ";
$lang['It appears your webhost is currently running PHP %s.'] = "Jusu webhosts patlaban izmanto PHP %s.";
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = "Piwigo var meginat parslegt Jusu konfiguraciju uz  PHP 5 izveidojot vai modificejot  a .htaccess failu.";
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = "Jus varat izmanit savu konfiguraciju pats un pec tam parstartet Piwigo.";
$lang['Try to configure PHP 5'] = "Meginiet nokonfiguret PHP 5";
$lang['Sorry!'] = "Atvainojiet!";
$lang['Piwigo was not able to configure PHP 5.'] = "Piwigo nevar nokonfiguret PHP 5.";
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = "Jums javeršas pie Jusu hostinga pakalpojuma sniedzeja pec palidzibas un pašam jamegina parslegties uz PHP 5 atbalstu.";
$lang['Hope to see you back soon.'] = "Ceram Jus redzet atkal.";
$lang['Congratulations, Piwigo installation is completed'] = 'Apsveicam, Piwigo instalacija ir pabeigta';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = ' Alternativa ir iekopet tekstu lodzina augšpuse un ielimet to faila "local/config/database.inc.php" (Uzmanibu : database.inc.php drikst saturet tikai to kas ir teksta lodzina, ne enter ne tukšumus)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Creation of config file local/config/database.inc.php failed.';
$lang['Download the config file'] = 'Lejupladet config failu';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Jums jalejupielade configuracijas fails un jaielade tas Jusu instalacijas local/config mape.';
$lang['SQLite and PostgreSQL are currently in experimental state.'] = 'SQLite un PostgreSQL patlaban darbojas eksperimentala režima.';
$lang['Learn more'] = 'Uzzini vairak';
?>

==> piwigo-2.2.5.zip: piwigo/language/lv_LV/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = "Instalacija";
$lang['Basic configuration'] = "Pamatkonfiguracija";
$lang['Default gallery language'] = "Galerijas valoda pec noklusešanas";
$lang['Database configuration'] = "Datubazes konfiguracija";
$lang['Admin configuration'] = "Administratora konfiguracija";
$lang['Start Install'] = "Sakt instalaciju";
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = "e-pasta adresei jaizskatas xxx@yyy.eee (piemeram : jack@altern.org)";
$lang['Webmaster login'] = "Webmastera logins";
$lang['It will be shown to the visitors. It is necessary for website administration'] = "Tas tiks radits apmekletajiem. Tas nepieciešams web lapas administrešanai";
$lang['Connection to server succeed, but it was impossible to connect to database'] = "Savienojums ar serveri sekmigs, bet savienojums ar datu bazi nav iespejams";
$lang['Can\'t connect to server'] = "Nevar savienoties ar serveri";
$lang['Database type'] = "Datubazes tips";
$lang['The type of database your piwigo data will be store in'] = "Datu bazes tips, kur tiks galbati Jusu Ptwigo dati.";
$lang['Host'] = "Hosts";
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = "localhost, sql.multimania.com, toto.freesurf.fr";
$lang['User'] = "Lietotajs";
$lang['user login given by your host provider'] = "lietotaja logins, ko pieškir Jusu hosta pakalpojuma sniedzejs";
$lang['Password'] = "Parole";
$lang['user password given by your host provider'] = " lietotaja parole, ko pieškir Jusu hosta pakalpojuma sniedzejs";
$lang['Database name'] = "Datu bazes nosaukums";
$lang['also given by your host provider'] = "ari pieškir Jusu hosta pakalpojuma sniedzejs";
$lang['Database table prefix'] = "Datu bazes tabulas prefikss";
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = "datu bazes tabulu nosaukumi bus ar šo prefiksu (lauj labak parvaldit Jusu tabulas)";
$lang['enter a login for webmaster'] = "ievadit webmastera loginu";
$lang['webmaster login can\'t contain characters \' or "'] = "webmastera logins nedrikst saturet ' vai \"";
$lang['please enter your password again'] = "ludzu ievadiet Jusu paroli no jauna";
$lang['Webmaster password'] = "Webmastera parole";
$lang['Keep it confidential, it enables you to access administration panel'] = "Esiet konfidenciali, tas lauj pieklut administratora panelim";
$lang['Password [confirm]'] = "Parole [apstiprinat]";
$lang['verification'] = "parbaude";
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = "Vajag palidzibu? Uzdodiet savu jautajumu <a href=\"%s\">Piwigo sludinajumos</a>.";
$lang['Webmaster mail address'] = 'Webmāstera pasta adrese';
$lang['Visitors will be able to contact site administrator with this mail'] = "Apmekletaji vares izmantot šo e-pastu, lai sazinatos ar lapas administratoru";
$lang['PHP 5 is required'] = "nepieciešams PHP 5 ";
$lang['It appears your webhost is currently running PHP %s.'] = "Jusu webhosts patlaban izmanto PHP %s.";
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = "Piwigo var meginat parslegt Jusu konfiguraciju uz  PHP 5 izveidojot vai modificejot  a .htaccess failu.";
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = "Jus varat izmanit savu konfiguraciju pats un pec tam parstartet Piwigo.";
$lang['Try to configure PHP 5'] = "Meginiet nokonfiguret PHP 5";
$lang['Sorry!'] = "Atvainojiet!";
$lang['Piwigo was not able to configure PHP 5.'] = "Piwigo nevar nokonfiguret PHP 5.";
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = "Jums javeršas pie Jusu hostinga pakalpojuma sniedzeja pec palidzibas un pašam jamegina parslegties uz PHP 5 atbalstu.";
$lang['Hope to see you back soon.'] = "Ceram Jus redzet atkal.";
$lang['Congratulations, Piwigo installation is completed'] = 'Apsveicam, Piwigo instalacija ir pabeigta';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = ' Alternativa ir iekopet tekstu lodzina augšpuse un ielimet to faila "local/config/database.inc.php" (Uzmanibu : database.inc.php drikst saturet tikai to kas ir teksta lodzina, ne enter ne tukšumus)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Konfigurācijas faila local/config/database.inc.php izveide ir nesekmīga.';
$lang['Download the config file'] = 'Lejupladet config failu';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Jums jalejupielade configuracijas fails un jaielade tas Jusu instalacijas local/config mape.';
$lang['SQLite and PostgreSQL are currently in experimental state.'] = 'SQLite un PostgreSQL patlaban darbojas eksperimentala režima.';
$lang['Learn more'] = 'Uzzini vairak';
?>
